@@ -35,7 +35,6 @@
 
 typedef struct
 {
-  GtkCssProvider *provider;
   GtdManager     *manager;
 
   GtkWidget      *window;
@@ -51,6 +50,14 @@ struct _GtdApplication
   GtdApplicationPrivate *priv;
 };
 
+static void           gtd_application_activate_action             (GSimpleAction        *simple,
+                                                                   GVariant             *parameter,
+                                                                   gpointer              user_data);
+
+static void           gtd_application_start_client                (GSimpleAction        *simple,
+                                                                   GVariant             *parameter,
+                                                                   gpointer              user_data);
+
 static void           gtd_application_show_extensions             (GSimpleAction        *simple,
                                                                    GVariant             *parameter,
                                                                    gpointer              user_data);
@@ -66,11 +73,33 @@ static void           gtd_application_quit                        (GSimpleAction
 G_DEFINE_TYPE_WITH_PRIVATE (GtdApplication, gtd_application, GTK_TYPE_APPLICATION)
 
 static const GActionEntry gtd_application_entries[] = {
+  { "activate", gtd_application_activate_action },
+  { "start-client", gtd_application_start_client },
   { "show-extensions",  gtd_application_show_extensions },
   { "about",  gtd_application_show_about },
   { "quit",   gtd_application_quit }
 };
 
+static void
+gtd_application_activate_action (GSimpleAction *simple,
+                                 GVariant      *parameter,
+                                 gpointer       user_data)
+{
+  GtdApplicationPrivate *priv = GTD_APPLICATION (user_data)->priv;
+
+  gtk_widget_show (priv->window);
+  gtk_window_present (GTK_WINDOW (priv->window));
+}
+
+static void
+gtd_application_start_client (GSimpleAction *simple,
+                              GVariant      *parameter,
+                              gpointer       user_data)
+{
+  /* TODO */
+  g_message ("Starting up client");
+}
+
 static void
 gtd_application_show_extensions (GSimpleAction *simple,
                                  GVariant      *parameter,
@@ -108,7 +137,7 @@ gtd_application_show_about (GSimpleAction *simple,
 
   date = g_date_time_new_now_local ();
 
-  if (g_date_time_get_year (date) == created_year)
+  if (g_date_time_get_year (date) <= created_year)
     {
       copyright = g_strdup_printf (_("Copyright \xC2\xA9 %d "
                                      "The To Do authors"), created_year);
@@ -164,15 +193,8 @@ run_window (GtdApplication *application)
 
   priv = application->priv;
 
-  if (!priv->window)
-    {
-      priv->window = gtd_window_new (GTD_APPLICATION (application));
-
-      gtk_window_set_transient_for (GTK_WINDOW (priv->plugin_dialog),
-                                    GTK_WINDOW (priv->window));
-    }
-
   gtk_widget_show (priv->window);
+  gtk_window_present (GTK_WINDOW (priv->window));
 }
 
 /*
@@ -219,38 +241,6 @@ run_initial_setup (GtdApplication *application)
 static void
 gtd_application_activate (GApplication *application)
 {
-  GtdApplicationPrivate *priv = GTD_APPLICATION (application)->priv;
-
-  if (!priv->provider)
-   {
-     GError *error = NULL;
-     GFile* css_file;
-
-     priv->provider = gtk_css_provider_new ();
-     gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                                                GTK_STYLE_PROVIDER (priv->provider),
-                                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION + 1);
-
-     css_file = g_file_new_for_uri ("resource:///org/gnome/todo/theme/Adwaita.css");
-
-     gtk_css_provider_load_from_file (priv->provider,
-                                      css_file,
-                                      &error);
-     if (error != NULL)
-       {
-         g_warning ("%s: %s: %s",
-                    G_STRFUNC,
-                    _("Error loading CSS from resource"),
-                    error->message);
-
-         g_error_free (error);
-       }
-     else
-       {
-         g_object_unref (css_file);
-       }
-   }
-
   /* FIXME: the initial setup is disabled for the 3.18 release because
    * we can't create tasklists on GOA accounts.
    */
@@ -266,7 +256,12 @@ gtd_application_finalize (GObject *object)
 static void
 gtd_application_startup (GApplication *application)
 {
-  GtdApplicationPrivate *priv = GTD_APPLICATION (application)->priv;
+  GtdApplicationPrivate *priv;
+  g_autoptr (GtkCssProvider) css_provider;
+  g_autoptr (GFile) css_file;
+  g_autofree gchar *theme_name, *theme_uri;
+
+  priv = GTD_APPLICATION (application)->priv;
 
   /* add actions */
   g_action_map_add_action_entries (G_ACTION_MAP (application),
@@ -276,11 +271,33 @@ gtd_application_startup (GApplication *application)
 
   G_APPLICATION_CLASS (gtd_application_parent_class)->startup (application);
 
+  /* manager */
+  priv->manager = gtd_manager_get_default ();
+
+  /* window */
+  priv->window = gtd_window_new (GTD_APPLICATION (application));
+
+  /* CSS provider */
+  css_provider = gtk_css_provider_new ();
+  gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+                                             GTK_STYLE_PROVIDER (css_provider),
+                                             GTK_STYLE_PROVIDER_PRIORITY_APPLICATION + 1);
+
+  g_object_get (gtk_settings_get_default (), "gtk-theme-name", &theme_name, NULL);
+  theme_uri = g_strconcat ("resource:///org/gnome/todo/theme/", theme_name, ".css", NULL);
+  css_file = g_file_new_for_uri (theme_uri);
+
+  if (g_file_query_exists (css_file, NULL))
+    gtk_css_provider_load_from_file (css_provider, css_file, NULL);
+  else
+    gtk_css_provider_load_from_resource (css_provider, "/org/gnome/todo/theme/Adwaita.css");
+
   /* plugin dialog */
   priv->plugin_dialog = gtd_plugin_dialog_new ();
 
-  /* manager */
-  priv->manager = gtd_manager_get_default ();
+  gtk_window_set_transient_for (GTK_WINDOW (priv->plugin_dialog), GTK_WINDOW (priv->window));
+
+  /* Load the plugins */
   gtd_manager_load_plugins (priv->manager);
 }
 
